#
# spec file for package python3-coverage
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-coverage
Version:        3.7.1
Release:        5.3
Url:            http://nedbatchelder.com/code/coverage/%{version}
Summary:        Code coverage measurement for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/c/coverage/coverage-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-setuptools
%if 0%{?suse_version} && 0%{?suse_version} <= 1310
BuildRequires:  python3-xml
Requires:       python3-xml
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
Coverage.py measures code coverage, typically during test execution. It uses
the code analysis tools and tracing hooks provided in the Python standard
library to determine which lines are executable, and which have been executed.

%prep
%setup -q -n coverage-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
rm %{buildroot}%{_bindir}/coverage
ln -s %{_bindir}/coverage-%{py3_ver} %{buildroot}/%{_bindir}/coverage

%pre
# Since /usr/bin/coverage became ghosted to be used with update-alternatives, we have
# to get rid of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/coverage ] | rm -f %{_bindir}/coverage

%post
update-alternatives \
    --install %{_bindir}/coverage coverage %{_bindir}/coverage-%{py3_ver} 30

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove coverage %{_bindir}/coverage-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc AUTHORS.txt CHANGES.txt README.txt
%ghost %{_bindir}/coverage
%{_bindir}/coverage3
%{_bindir}/coverage-%{py3_ver}
%{python3_sitearch}/coverage
%{python3_sitearch}/coverage-%{version}-py%{py3_ver}.egg-info

%changelog
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu May  8 2014 toddrme2178@gmail.com
- update to 3.7.1:
  - Improved the speed of HTML report generation by about 20%%.
  - Fixed the mechanism for finding OS-installed static files for the HTML report
    so that it will actually find OS-installed static files.
- update to 3.7:
  * Added the ``--debug`` switch to ``coverage run``.  It accepts a list of
  options indicating the type of internal activity to log to stderr.
  * Running code with ``coverage run -m`` now behaves more like Python does,
  setting sys.path properly, which fixes `issue 207`_ and `issue 242`_.
  * Coverage can now run .pyc files directly, closing `issue 264`_.
  * Over 15 other bugfixes, see included CHANGELOG
- Require python-setuptools instead of distribute (upstreams merged)
* Wed May 15 2013 speilicke@suse.com
- Fix update-alternatives and support upgrade from previous versions
* Fri May  3 2013 speilicke@suse.com
- Buildrequire python3 to get acces to the 'sha512' module (not part
  of python3-base which comes through python3-devel)
* Fri May  3 2013 speilicke@suse.com
- Apply update-alternatives for binaries and man-pages
- Drop buildrequires on python-xml, I don't see it being used
* Mon Apr 29 2013 dmueller@suse.com
- update to 3.6:
  * Fix Nose support
  * Add --fail-under
  * Over 20 bug fixes, for details see included CHANGELOG
* Tue Nov 20 2012 saschpe@suse.de
- Update to version 3.5.3:
  + Line numbers in the HTML report line up better with the source lines, fixing
    issue 197
  + When specifying a directory as the source= option, the directory itself no
    longer needs to have a __init__.py file, though its subdirectories do, to
    be considered as source files.
  + Files encoded as UTF-8 with a BOM are now properly handled, fixing
    issue 179_.
  + Fixed more cases of non-Python files being reported as Python source, and
    then not being able to parse them as Python.  Closes issue 82 (again).
  + Fixed memory leaks under Python 3, thanks, Brett Cannon. Closes issue 147_.
  + Optimized .pyo files may not have been handled correctly, issue 195_.
  + Certain unusually named file paths could have been mangled during reporting,
    issue 194_.
  + Try to do a better job of the impossible task of detecting when we can't
    build the C extension, fixing issue 183_.
  + Testing is now done with tox
- Changes from version 3.5.2:
  + No changes since 3.5.2.b1
- Changes from version 3.5.2b1
  + The HTML report has slightly tweaked controls: the buttons at the top of
    the page are color-coded to the source lines they affect.
  + Custom CSS can be applied to the HTML report by specifying a CSS file as
    the extra_css configuration value in the [html] section.
  + Source files with custom encodings declared in a comment at the top are now
    properly handled during reporting on Python 2.  Python 3 always handled them
    properly.  This fixes issue 157_.
  + Backup files left behind by editors are no longer collected by the source=
    option, fixing issue 168_.
  + If a file doesn't parse properly as Python, we don't report it as an error
    if the filename seems like maybe it wasn't meant to be Python.  This is a
    pragmatic fix for issue 82_.
  + The -m switch on coverage report, which includes missing line numbers
    in the summary report, can now be specifed as show_missing in the
    config file.  Closes issue 173_.
  + When running a module with coverage run -m <modulename>, certain details
    of the execution environment weren't the same as for
    python -m <modulename>.  This had the unfortunate side-effect of making
    coverage run -m unittest discover not work if you had tests in a
    directory named "test".  This fixes issue 155_.
  + Now the exit status of your product code is properly used as the process
    status when running python -m coverage run ....  Thanks, JT Olds.
  + When installing into pypy, we no longer attempt (and fail) to compile
    the C tracer function, closing issue 166_.
- Name Python3 binaries consistently:
  + Fix in setup.py to have correct egg-info data
* Thu Sep  6 2012 toddrme2178@gmail.com
- Restore BuildRequires: python3  This package depends on hash
  algorithms that are only available if python3 is installed,
  python3-devel will not pull them in.  Building will fail if
  BuildRequires: python3 is removed.
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3-coverage package added
